DottedLoader class
A loader that displays a row of dots that are filled sequentially. Usage example
DottedLoader()
Also you sets the following parameters to customize the loader
ballsCount -> sets the number of rotating balls.
loaderWidth -> sets the width of the loader.
ballRadius -> sets the radius to the rotating balls.
ballsColor -> sets the color of the balls.
ballsFillColor -> sets the color of the progress balls.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DottedLoader
Constructors
Properties
- ballRadius → double
-
The radius of each ball in the loader.
final
- ballsColor → Color
-
The color of the balls when they are not filled.
final
- ballsCount → int
-
The number of balls in the loader.
final
- ballsFillColor → Color
-
The color of the balls when they are filled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loaderWidth → double
-
The width of the entire loader.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< DottedLoader> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited