RotatingCirclesLoader class

A loader that displays rotating circles around a central point. Usage example

RotatingCirclesLoader()

Also you sets the following parameters to customize the loader

ballsCount -> sets the number of rotating balls.

loaderRadius -> sets the radius of the loader.

ballRadius -> sets the radius to the rotating balls.

ballsColor -> sets the color of the balls.

Inheritance

Constructors

RotatingCirclesLoader({Key? key, int ballsCount = 6, double loaderRadius = 30, double ballRadius = 5, Color ballsColor = Colors.white})
Creates a rotating circles loader.
const

Properties

ballRadius double
The radius of each ball in the loader.
final
ballsColor Color
The color of the balls.
final
ballsCount int
The number of balls in the loader.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loaderRadius double
The radius of the entire loader circle.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<RotatingCirclesLoader>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited