enabledHeight property
enabledHeight refers the height of the gesture detector which can be used for dragging
Implementation
final double enabledHeight;
enabledHeight refers the height of the gesture detector which can be used for dragging
final double enabledHeight;