enabledWidth property
enabledWidth refers the width of the gesture detector which can be used for dragging
Implementation
final double enabledWidth;
enabledWidth refers the width of the gesture detector which can be used for dragging
final double enabledWidth;