onChangeStart property
onChangeStart Callback function. Called whenever the progressbar's current value starts to be changed. It is only called when the progressbar is dragged.
Implementation
final ValueChanged<double>? onChangeStart;
onChangeStart Callback function. Called whenever the progressbar's current value starts to be changed. It is only called when the progressbar is dragged.
final ValueChanged<double>? onChangeStart;