progress_bar library

Classes

HorizontalProgressBar
The class HorizontalProgressBar is used to create a horizontal progress bar. The required parameters of the HorizontalProgressBar are maxValue, currentPosition and onChanged
VerticalProgressBar
The class VerticalProgressBar is used to create a vertical progress bar. The required parameters of the VerticalProgressBar are height, maxValue, currentPosition and onChanged